#
# spec file for package python-ipdb
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define skip_python39 1
Name:           python-ipdb
Version:        0.13.13
Release:        3.1
Summary:        IPython-enabled pdb
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/gotcha/ipdb
Source:         https://files.pythonhosted.org/packages/source/i/ipdb/ipdb-%{version}.tar.gz
BuildRequires:  %{python_module decorator}
BuildRequires:  %{python_module ipython >= 7.16.3 if %python-base < 3.7}
BuildRequires:  %{python_module ipython >= 7.31.1 if %python-base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tomli if %python-base < 3.11}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-decorator
Requires:       (python-ipython >= 7.16.3 if python-base < 3.7)
Requires:       (python-ipython >= 7.31.1 if python-base >= 3.7)
Requires:       (python-tomli if python-base < 3.11)
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       python-jupyter_ipdb = %{version}
Obsoletes:      python-jupyter_ipdb < %{version}
BuildArch:      noarch
%if "%{python_flavor}" == "python3" || "%{?python_provides}"  == "python3"
Provides:       jupyter-ipdb = %{version}
%endif
%python_subpackages

%description
ipdb exports functions to access the IPython_ debugger, which features
tab completion, syntax highlighting, better tracebacks, better
introspection with the same interface as the `pdb` module.

%prep
%setup -q -n ipdb-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/ipdb3
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative ipdb3

%postun
%python_uninstall_alternative ipdb3

%check
%pyunittest -v

%files %{python_files}
%doc AUTHORS HISTORY.txt README.rst
%license COPYING.txt
%python_alternative %{_bindir}/ipdb3
%{python_sitelib}/ipdb
%{python_sitelib}/ipdb-%{version}.dist-info

%changelog
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19
* Wed Jul 19 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sun Mar 19 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.13.13
  * Use context manager for opening toml config
- Release 0.13.12
  * Modify tests to test 3.11 separately from earlier python
    versions.
* Sun Dec 25 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.13.11
  * Better exception handling when looking for config.
    [bignose-debian]
- Release 0.13.10
  * Better toml support (use tomlib for 3.11, tomli for 3.6 to
    3.10). [salty-horse, mgorny]
  * Minimal PEP 517 support. [cpcloud]
  * 3.11 support for run as module and run as script. [nphilipp,
    gotcha]
  * Based on OSV:PYSEC-2022-12 change ipython dependencies
* Sun Sep 19 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.13.9
  * Add the convenience function ``iex()`
  * Do not instantiate IPython on import
  * Add support for pyproject.toml as configuration file
* Tue Dec 15 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 0.13.4
  * Add '-m' option [mrmino]
- Switch to pyunittest macro to avoid external mock package
- Upstream calls the entrypoint ipdb3, no reason to be different,
  call proper python_clone for it.
- Provide the old jupyter package name only for the primary
  Python3 interpreter -- gh#openSUSE/python-rpm-macros#66
* Mon Jun 29 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.13.3
  * Allow runcall, runeval to also use set context value
  * Add condition argument to set_trace
  * Add option to set context via environment variable or configuration file
* Tue Mar  3 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.13.2
  * Remove leftover debug code
- Update to 0.13.1
  * Fix when no configuration file
- Update to 0.13.0
  * Add option to set context via environment variable or configuration file.
* Fri Jan  3 2020 Todd R <toddrme2178@gmail.com>
- Update to 0.12.3
  * Fix version in usage
- Drop python2 support due to dependencies dropping python2
* Sun Oct 13 2019 Axel Braun <axel.braun@gmx.de>
- runtime dependency on python-ipython added
* Fri Sep 13 2019 John Vandenberg <jayvdb@gmail.com>
- Skip the bin install commands if the flavor is not being built
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.12.2
  * Avoid emitting term-title bytes
* Sat Jul 27 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.12.1
  * Fix --help
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.12.0
  * Drop support for Python 3.3.x
  * Stop deprecation warnings from being raised when IPython >= 5.1 is used.
    Support for IPython < 5.1 has been dropped.
- Rename to to match python package naming guidelines.
* Fri Jan 18 2019 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for 0.11
